@@ -7,6 +7,7 @@
 use util::StrCharIndex;
 use index_japanese as index;
 use types::*;
+use self::ISO2022JPState::{ASCII,Katakana,Lead};
 
 /**
  * EUC-JP. (XXX with asymmetric JIS X 0212 support)
@@ -164,6 +165,8 @@ mod eucjp_tests {
     use std::iter::range_inclusive;
     use testutils;
     use types::*;
+    use types::DecoderTrap::Strict as DecodeStrict;
+    use types::EncoderTrap::Strict as EncodeStrict;
 
     #[test]
     fn test_encoder_valid() {
@@ -520,6 +523,8 @@ mod windows31j_tests {
     use std::iter::range_inclusive;
     use testutils;
     use types::*;
+    use types::DecoderTrap::Strict as DecodeStrict;
+    use types::EncoderTrap::Strict as EncodeStrict;
 
     #[test]
     fn test_encoder_valid() {
@@ -917,6 +922,9 @@ mod iso2022jp_tests {
     use super::ISO2022JPEncoding;
     use testutils;
     use types::*;
+    use types::DecoderTrap::Replace as DecodeReplace;
+    use types::DecoderTrap::Strict as DecodeStrict;
+    use types::EncoderTrap::Strict as EncodeStrict;
 
     #[test]
     fn test_encoder_valid() {
